@@ -144,10 +144,6 @@ class ProcfileWatcher(CircusPlugin):
             "stderr_stream": stderr_stream,
             "stdout_stream": stdout_stream,
             "uid": self.uid,
-            "hooks": {
-                'before_start': ['tsuru.hooks.before_start', False],
-                'after_start': ['tsuru.hooks.after_start', False],
-            }
         }
         self.circus_client.call(json.dumps({
             "command": "add",
